================
enpt_enmapboxapp
================

A QGIS EnMAPBox plugin providing a GUI for the EnMAP processing tools (EnPT).


* Free software: GNU General Public License v3
* Documentation: http://enmap.gitext.gfz-potsdam.de/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/doc/

.. image:: ./docs/images/screenshot_enpt_enmapboxapp_874x1267.png
    :width: 874 px
    :height: 1267 px
    :scale: 100 %


Status
------

.. image:: https://gitext.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/badges/master/pipeline.svg
        :target: https://gitext.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/commits/master
.. image:: https://img.shields.io/pypi/v/enpt_enmapboxapp.svg
        :target: https://pypi.python.org/pypi/enpt_enmapboxapp
.. image:: https://gitext.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/badges/master/coverage.svg
        :target: https://gitext.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/coverage/
.. image:: https://img.shields.io/static/v1?label=Documentation&message=GitLab%20Pages&color=orange
        :target: http://enmap.gitext.gfz-potsdam.de/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/doc/
.. image:: https://img.shields.io/pypi/l/enpt_enmapboxapp.svg
        :target: https://gitext.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/blob/master/LICENSE
.. image:: https://img.shields.io/pypi/pyversions/enpt_enmapboxapp.svg
        :target: https://img.shields.io/pypi/pyversions/enpt_enmapboxapp.svg
.. image:: https://img.shields.io/pypi/dm/enpt_enmapboxapp.svg
        :target: https://pypi.python.org/pypi/enpt_enmapboxapp

.. .. image:: https://img.shields.io/travis/danschef/enpt_enmapboxapp.svg
        :target: https://travis-ci.org/danschef/enpt_enmapboxapp

.. .. image:: https://readthedocs.org/projects/enpt-enmapboxapp/badge/?version=latest
        :target: https://enpt-enmapboxapp.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. .. image:: https://pyup.io/repos/github/danschef/enpt_enmapboxapp/shield.svg
     :target: https://pyup.io/repos/github/danschef/enpt_enmapboxapp/
     :alt: Updates

See also the latest coverage_ report and the nosetests_ HTML report.


Installation
------------

Clone the repository and install enpt_enmapboxapp to your local QGIS python:

.. code-block:: console

    git clone https://gitext.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp.git
    cd enpt_enmapboxapp
    pip install .


Credits
-------
This software was developed within the context of the EnMAP project supported by the DLR Space Administration with
funds of the German Federal Ministry of Economic Affairs and Energy (on the basis of a decision by the German
Bundestag: 50 EE 1529) and contributions from DLR, GFZ and OHB System AG.

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _coverage: http://enmap.gitext.gfz-potsdam.de/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/coverage/
.. _nosetests: http://enmap.gitext.gfz-potsdam.de/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/nosetests_reports/nosetests.html
